Updated structure. Merged global with base to centralise all global/base styles that will apply regardless of elements.

Seperate custom property definitions by context

## Upgrades

- Upgrade `normalize.css` to `v8.0.0`
- Change PostCSS dependancy from postcss-cssnext to postcss-preset-env.
- Update dependancies to latest compatible major versions
- Commit package-lock.json
- Updated color() function to color-mod() (stage 2) CSS spec https://www.w3.org/TR/css-color-4/#funcdef-color-mod

## Breaking Changes

- Removed `@apply` rules and remove `_mixins.css` definitions along with documentation
- Removed `--gutter` and utity classes in preference for `--container-gutter` being set on the container element only
- Removed `--margin-*` and `--padding-*` custom property definitions in preference for `--space` avoiding duplicate values
- Removed font size responsive declarations for `:root` element, it's not being used, has no real benefit and is easy to update manually
- Removed `--input-*-padding` and `--select-*-padding` custom property definitions as `input` and `select` sizes already use relative padding size (`em`) and this is not required
- Removed `@apply` from `progress` and `input[type="range"]` elements
- Removed `.big` typography styles
- Removed `.small-caps` typography styles
- Removed `left-*` and `right-*` float utility classes (along with responsive breakpoint classes)
- Renamed `text-*` utility alignment classes to `.text-align-*` and text-transform utility classes to `.text-transform-*`
- Refactored `button-icon` sizing to add sizing for each size under `--button-icon-*-size` variable definitions, these sizes are inhertited by the `<svg>` element within a `.button-icon` element without the need for an `icon-*` class

## Additions

- Added xxs, and xxl varients for all global classes (`font-size`, `line-height`, etc.) elements (`input`, `button`, etc.) and `@media` query breakpoints
- Added support for `control-reversed` modifier
- Added support for `[disabled]` attribute on `<a class="button ...">`
- Added space utility classes to add `width` and `height` to an element based on `--space-*` custom property defintions
- Added `.all-caps` as a replacement for `.small-caps` with size variants for greater flexibility
- Extended `.display-title` with size variants for greater flexibility
- Extended `.lead` with size variants for greater flexibility
- Added `.group` base class size variants to be places on wrappers of `<ul>` lists with margins applied to `<li>` elements within
- Added `--spinner-width` to control the thickness of the `.spinner` element
- Added support for `.spinner-*` sizes
- Added `.box-shadow-*` sizes and utility classes
- Add `margin-negative-*` utility classes for all sizes
- Add `margin-vertical-*` utility classes for relative sizes (em) including 1, 3-4, 1-2, 1-4
- Add `min-height-*` utility classes `vh` based `min-height` settings
- Add `order-*` utility classes for 1, 2, 3 and aliases first, middle, last
- Added `.button-text` modifier class
- Added `.font-family`, `.font-weight`, `.font-size`, `.line-height`, `.letter-spacing`, and `.box-shadow` utility classes for base settings
- Added `--link-text-decoration-skip` and `--link-hover-text-decoration-skip` for links
- Added `--all-caps-color` variable definition
- Added `--label-text-transform` and `--label-letter-spacing` variable definitions
- Added `--control-label-font-family`, `--control-label-font-weight`, `--control-label-font-size`, `--control-label-line-height`, `--control-label-text-transform`, `--control-label-letter-spacing` variable definitions
- Added `--definition-term-line-height` and `--definition-description-line-height` variable definitions

## Fixes

- Added `.table-responsive` to margin reset
- Fixed `.button-group` not resetting `border-radius` for direct decendants
- Removed `height` from being set on `input[type="range"]` with `height: auto`
- Updated `package.json` scripts to be more descriptive and meaningful
- Fixed `.control` check indicator border color to default to checked background color
- Updated `.control:checked` indicator SVG glyph, no longer `base64` but rather `utf-8` encoding for editing and scaling purposes
- Removed `:not(:disabled)` from `input`, `.field-float-label`, `select`, and `button` styles
- Fix direct child `<ul>` / `<ol>` of `<li>` recieving styles to avoid nested markup inheriting styles
- Add `px` affix to `flex-1` utility class flex property value: `flex: 1 1 0px` for IE support

## Style Changes

- Tighten global `--space-*` sizes
- Increase default global `--border-radius` custom property definition to `0.125rem` (`4px`)
- Update default global `--max-width` and `--letter-spacing` custom property definitions to have generic scales
- Tightened `progress` and `input[type="range"]` heights
- Tightened `.control` size scale
- Decrease default global `--label-magin` custom property definition
- Update default global `--field-magin` and `--range-magin` custom property definition
- Updated default `<pre>` and `<code>` styles
- Updated default `-icon-*` sizes

## Documentation

- Removed `<mark>` indicator variants
- Add prettier formatter for `.md` markdown files
